# yapx

|               |                                           |
| ------------- | ----------------------------------------- |
| Repo          | https://codeberg.org/Fresh2dev/yapx       |
| Repo Mirror   | https://www.Fresh2.dev/code/r/yapx        |
| Documentation | https://www.Fresh2.dev/code/r/yapx/i/docs |
| Funding       | https://www.Fresh2.dev/tip                |

---

## Build

```sh
myke py-mkdocs
```

## Deploy

```sh
myke stack-up
```
